<!DOCTYPE html>
<html>
<head><title>Step 11 - CSV List</title></head>
<body>
    <h1>User List (Read)</h1>
    <table border="1">
        <tr><th>ID</th><th>Name</th><th>Age</th></tr>
        {% for user in users %}
        <tr>
            <td>{{ user.id }}</td>
            <td>{{ user.name }}</td>
            <td>{{ user.age }}</td>
        </tr>
        {% endfor %}
    </table>
</body>
</html>
