<!DOCTYPE html>
<html>
<head><title>Step 10 - Result</title></head>
<body>
    <h1>Template Echo Result</h1>
    <p>You typed: <strong>{{ message }}</strong></p>
    <p><a href="/">Back</a></p>
</body>
</html>
