<!DOCTYPE html>
<html>
<head><title>Step 19 - User Detail</title></head>
<body>
    <h1>User Detail</h1>
    <ul>
        <li>ID: {{ user.id }}</li>
        <li>Name: {{ user.name }}</li>
        <li>Age: {{ user.age }}</li>
    </ul>
    <p>
        <a href="/user/{{ user.id }}/edit">Edit</a> |
        <a href="/">Back to List</a>
    </p>
</body>
</html>
